@@ -100,6 +100,8 @@ class App(object):
 
                 func = importlib.import_module('.'.join(home_parts)[:-3]).main
                 self.add_route(route, func, method='POST', **kwargs)
+            else:
+                logger.warning(f"Filter: {p.stem}")
 
         logger.info(f"Add Routes: {routes}")
 
