@@ -50,7 +50,7 @@ def run(app_file: str, app='fastapi', port=9955, nohup=0):
 
 # 一键起服务
 @cli.command()
-def easy_run(app_dir: str, port=8000, access_log=True):
+def easy_run(app_dir: str, port=8051, access_log: bool = True):
     from appzoo import App
 
     app = App()
